@@ -3,7 +3,7 @@ from . import cloud_wanderer_resource, storage_connectors
 from .aws_interface import CloudWandererAWSInterface
 from .cloud_wanderer import CloudWanderer
 from .cloud_wanderer_resource import CloudWandererResource
-from .models import ResourceFilter
+from .models import ServiceResourceType
 from .urn import URN
 
 __all__ = [
@@ -13,5 +13,5 @@ __all__ = [
     "CloudWanderer",
     "URN",
     "CloudWandererAWSInterface",
-    "ResourceFilter",
+    "ServiceResourceType",
 ]
